/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/* SPDX-FileCopyrightText: 2017 Sébastien Wilmet <swilmet@gnome.org>
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DH_INIT_H
#define DH_INIT_H

#include <glib.h>

G_BEGIN_DECLS

void    dh_init         (void);
void    dh_finalize     (void);

G_END_DECLS

#endif /* DH_INIT_H */
