/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/* SPDX-FileCopyrightText: 2012 Aleksander Morgado <aleksander@gnu.org>
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#ifndef DEVHELP_H
#define DEVHELP_H

/* Include all the public headers. */

#include <devhelp/dh-enum-types.h>

#include <devhelp/dh-application-window.h>
#include <devhelp/dh-assistant-view.h>
#include <devhelp/dh-book.h>
#include <devhelp/dh-book-list.h>
#include <devhelp/dh-book-list-builder.h>
#include <devhelp/dh-book-list-directory.h>
#include <devhelp/dh-book-manager.h>
#include <devhelp/dh-book-tree.h>
#include <devhelp/dh-completion.h>
#include <devhelp/dh-init.h>
#include <devhelp/dh-keyword-model.h>
#include <devhelp/dh-link.h>
#include <devhelp/dh-notebook.h>
#include <devhelp/dh-profile.h>
#include <devhelp/dh-profile-builder.h>
#include <devhelp/dh-search-bar.h>
#include <devhelp/dh-settings.h>
#include <devhelp/dh-settings-builder.h>
#include <devhelp/dh-sidebar.h>
#include <devhelp/dh-tab.h>
#include <devhelp/dh-tab-label.h>
#include <devhelp/dh-web-view.h>

#endif /* DEVHELP_H */
